/* extension.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported init */

const Main = imports.ui.main;
const LM = Main.layoutManager;
const MT = Main.messageTray;
const Display = global.display;

class Extension {
	constructor() {
	}

	enable() {
		this._original_updateState = MT._updateState;
		this._original_getDraggableWindowForPosition = Main.panel._getDraggableWindowForPosition;
		this._primary_monitor = LM.primaryMonitor;
		this._target_monitor = this.get_target_monitor()
		this.create_notifications_constraint(this._primary_monitor);
		this.move_all(this._target_monitor);
	}

	disable() {
		Display.disconnect(this._on_fullscreen);
		MT._updateState = this._original_updateState;
		Main.panel._getDraggableWindowForPosition = this._original_getDraggableWindowForPosition;
		delete MT._constraint;
	}

	create_notifications_constraint(monitor) {
		const constraint = MT.get_constraints()[0];
		if (constraint) {
			constraint.index = monitor.index;
			MT._constraint = constraint;
		}
	}

	get_target_monitor() {
		for (const monitor of LM.monitors) {
			if (monitor.index !== this._primary_monitor) {
				return monitor;
			}
		}
	}

	move_all(monitor) {
		if (this._panel_monitor_index !== monitor.index) {
			this.move_panel(monitor);
			this.move_hotcorners(monitor);
			this.move_notifications(monitor);
		}
	}

	move_panel(monitor) {
		LM.panelBox.set_position(monitor.x, monitor.y);
		LM.panelBox.set_size(monitor.width, -1);
		LM.panelBox.visible = true;
	}
	
	move_hotcorners(monitor) {    
		const old_index = LM.primaryIndex;
		LM.primaryIndex = monitor.index;
		LM._updateHotCorners();
		LM.primaryIndex = old_index;
	}
	
	move_notifications(monitor) {    
		MT._constraint.index = monitor.index;
	}
}

function init() {
	return new Extension();
}
